==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/FloatingPaneResizeEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { SplitPane } from "./SplitPane";
import { ResizerLocation_$type } from "./ResizerLocation";
/**
 * @hidden
 */
var FloatingPaneResizeEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FloatingPaneResizeEventArgsDetail, _super);
    function FloatingPaneResizeEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(FloatingPaneResizeEventArgsDetail.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatingPaneResizeEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.c.n = this.e;
        },
        enumerable: false,
        configurable: true
    });
    FloatingPaneResizeEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(FloatingPaneResizeEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.d.l("sourcePane", function (a) { return new SplitPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("sourcePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatingPaneResizeEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.d.m("resizerLocation");
            ret_ = enumGetBox(ResizerLocation_$type, EnumUtil.getEnumValue(ResizerLocation_$type, this.d.f(ResizerLocation_$type, ret_)));
            return EnumUtil.getEnumValue(ResizerLocation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ResizerLocation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.d.u("resizerLocation", value_);
        },
        enumerable: false,
        configurable: true
    });
    FloatingPaneResizeEventArgsDetail.$t = markType(FloatingPaneResizeEventArgsDetail, 'FloatingPaneResizeEventArgsDetail');
    return FloatingPaneResizeEventArgsDetail;
}(Base));
export { FloatingPaneResizeEventArgsDetail };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/FloatingPaneResizeEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { SplitPane } from "./SplitPane";
import { ResizerLocation_$type } from "./ResizerLocation";
/**
 * @hidden
 */
var FloatingPaneResizeEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FloatingPaneResizeEventArgsDetail, _super);
    function FloatingPaneResizeEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(FloatingPaneResizeEventArgsDetail.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatingPaneResizeEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.c.o = this.e;
        },
        enumerable: false,
        configurable: true
    });
    FloatingPaneResizeEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(FloatingPaneResizeEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.d.m("sourcePane", function (a) { return new SplitPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("sourcePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FloatingPaneResizeEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.d.n("resizerLocation");
            ret_ = enumGetBox(ResizerLocation_$type, EnumUtil.getEnumValue(ResizerLocation_$type, this.d.f(ResizerLocation_$type, ret_)));
            return EnumUtil.getEnumValue(ResizerLocation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ResizerLocation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("resizerLocation", value_);
        },
        enumerable: false,
        configurable: true
    });
    FloatingPaneResizeEventArgsDetail.$t = markType(FloatingPaneResizeEventArgsDetail, 'FloatingPaneResizeEventArgsDetail');
    return FloatingPaneResizeEventArgsDetail;
}(Base));
export { FloatingPaneResizeEventArgsDetail };
